@@ -56,20 +56,20 @@ GSGrab  * gs_grab_new              (void);
 void      gs_grab_release          (GSGrab    *grab);
 gboolean  gs_grab_release_mouse    (GSGrab    *grab);
 
-gboolean  gs_grab_grab_window      (GSGrab    *grab,
-                                    GdkWindow *window,
-                                    GdkScreen *screen,
-                                    gboolean   hide_cursor);
+gboolean  gs_grab_grab_window      (GSGrab     *grab,
+                                    GdkWindow  *window,
+                                    GdkDisplay *display,
+                                    gboolean    hide_cursor);
 
 gboolean  gs_grab_grab_root        (GSGrab    *grab,
                                     gboolean   hide_cursor);
 gboolean  gs_grab_grab_offscreen   (GSGrab    *grab,
                                     gboolean   hide_cursor);
 
-void      gs_grab_move_to_window   (GSGrab    *grab,
-                                    GdkWindow *window,
-                                    GdkScreen *screen,
-                                    gboolean   hide_cursor);
+void      gs_grab_move_to_window   (GSGrab     *grab,
+                                    GdkWindow  *window,
+                                    GdkDisplay *display,
+                                    gboolean    hide_cursor);
 
 void      gs_grab_mouse_reset      (GSGrab    *grab);
 void      gs_grab_keyboard_reset   (GSGrab    *grab);
